===============================
Aircrack-ng python 'bindings'
===============================

.. image:: https://img.shields.io/pypi/v/pyrcrack.svg
        :target: https://pypi.python.org/pypi/pyrcrack

.. image:: https://img.shields.io/travis/XayOn/pyrcrack.svg
        :target: https://travis-ci.org/XayOn/pyrcrack

.. image:: https://readthedocs.org/projects/pyrcrack/badge/?version=latest
        :target: https://readthedocs.org/projects/pyrcrack/?badge=latest
        :alt: Documentation Status


Simple aircrack-ng implementation in python, giving access to common commands and way to read its output / control its execution

* Free software: ISC license
* Documentation: https://pyrcrack.readthedocs.org.

Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
